cache_home
----------

.. currentmodule:: cbgen

Downloaded example files are stored at the :data:`BGEN_CACHE_HOME`
folder.

.. doctest::

   >>> from cbgen import BGEN_CACHE_HOME
   >>> BGEN_CACHE_HOME.is_dir()
   True
